@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2013 Jamie Zawinski <jwz@jwz.org>
+ * Copyright © 1991-2023 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -160,11 +160,11 @@ real_window_level(long pref) {
   window = [[DaliClockWindow alloc]
             initWithContentRect:rect
                       styleMask:(title_p
-                                 ? (NSTitledWindowMask |
-                                    NSClosableWindowMask |
-                                    NSMiniaturizableWindowMask |
-                                    NSResizableWindowMask)
-                                 : (NSBorderlessWindowMask))
+                                 ? (NSWindowStyleMaskTitled |
+                                    NSWindowStyleMaskClosable |
+                                    NSWindowStyleMaskMiniaturizable |
+                                    NSWindowStyleMaskResizable)
+                                 : (NSWindowStyleMaskBorderless))
                         backing:NSBackingStoreBuffered
                           defer:YES
                          screen:screen];
