@@ -116,6 +116,53 @@ char *progname = "Dali Clock";   // digital.c wants this for error messages.
   if ([self isPreview] ||
       [[self window] screen] == [[NSScreen screens] objectAtIndex:0])
     [clockView setAutoDate:67];
+
+
+# if 0
+  /* As of 10.8 or so, when the screen is locked, our background is no
+     longer transparent. Well, it is, but there's a masking window below us.
+     I'd like to find a way to make that window transparent too, so that if
+     the user has selected a less-than-fully-opaque background color, their
+     desktop will show through the locked screen.
+
+     I've managed to identify the masking windows, but I don't know how to
+     draw onto them with an opaque rectangle, or resize them, or unmap them,
+     or anything.  How do I get the CGContextRef for a window that I didn't
+     create?  Maybe that's not possible?
+   */
+  NSScreen *screen = [[self window] screen];
+  NSDictionary *sinfo = [screen deviceDescription];
+  NSNumber *sid = [sinfo objectForKey:@"NSScreenNumber"];
+  NSArray *windows = (NSArray *)
+    CGWindowListCopyWindowInfo(kCGWindowListOptionOnScreenOnly,
+                               kCGNullWindowID);
+
+  int n = [windows count];
+  for (int i = 0; i < n; i++) {
+    NSDictionary *desc = [windows objectAtIndex:i];
+    NSString *owner = [desc objectForKey:@"kCGWindowOwnerName"];
+    if (owner &&
+        ([owner isEqualToString:@"ScreenSaverEngine"] ||
+         [owner isEqualToString:@"loginwindow"])) {
+      if ([[desc objectForKey:@"kCGWindowLayer"] integerValue]
+          >= kCGScreenSaverWindowLevelKey) {
+        int id = [[desc objectForKey:@"kCGWindowNumber"] integerValue];
+        
+        // This just gives me [self window] of this saver or the saver on
+        // the other screen, not the shielding window.
+        NSWindow *w = [[NSApplication sharedApplication]
+                        windowWithWindowNumber:id];
+        NSLog(@"%d %@ %@", id, w);
+
+//        CGContextRef cgc = ###;
+//        CGRect r = CGRectMake (0, 100, 200, 300);
+//        CGContextSetGrayFillColor (cgc, 1, 0);
+//        CGContextFillRect (cgc, r);
+      }
+    }
+  }
+  CFRelease (windows);
+# endif // 0
 }
 
 /*
