@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2018 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 1991-2020 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -56,6 +56,27 @@ static void rgb_to_hsv (CGFloat r, CGFloat g, CGFloat b,
 
 
 @implementation DaliClockView
+{
+  GLuint textures[2];
+
+  NSTimer *clockTimer;
+  NSTimer *colorTimer;
+  NSTimer *dateTimer;
+  NSTimer *countdownHomeStretchStartTimer;
+  NSTimer *countdownHomeStretchEndTimer;
+  float autoDateInterval;
+
+  BOOL ownWindow;
+  BOOL constrainSizes;
+  BOOL usesCountdownTimer;
+  BOOL usesHomeStretchTimer;
+  NSDate *countdownDate;
+
+  NSColor *fg;
+  NSColor *bg;
+  NSColor *initialForegroundColor;
+  NSColor *initialBackgroundColor;
+}
 
 static NSUserDefaultsController *staticUserDefaultsController = 0;
 
@@ -131,6 +152,7 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
     [NSArchiver archivedDataWithRootObject:defbg], @"initialBackgroundColor",
     @"10.0", @"cycleSpeed",
     @"NO", @"usesCountdownTimer",
+    @"YES", @"usesHomeStretchTimer",
     defdate,@"countdownDate",
     nil];
 
@@ -165,6 +187,10 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
        toObject:controller
     withKeyPath:@"values.usesCountdownTimer"
         options:nil];
+  [self    bind:@"usesHomeStretchTimer"
+       toObject:controller
+    withKeyPath:@"values.usesHomeStretchTimer"
+        options:nil];
   [self    bind:@"countdownDate"
        toObject:controller
     withKeyPath:@"values.countdownDate"
@@ -192,6 +218,7 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
   [self setDateStyle:(int)[defaults integerForKey:@"dateStyle"]];
   [self setCycleSpeed:[defaults floatForKey:@"cycleSpeed"]];
   [self setUsesCountdownTimer:[defaults boolForKey:@"usesCountdownTimer"]];
+  [self setUsesHomeStretchTimer:[defaults boolForKey:@"usesHomeStretchTimer"]];
   [self setCountdownDate:(NSDate *)[defaults objectForKey:@"countdownDate"]];
 
   /* Is it a problem that I'm using NSKeyedUnarchiver on an object
@@ -937,6 +964,10 @@ FAIL:
     // that is not currently on screen.  If we don't do this, then the window
     // flickers if it is above another window that has video playing in it.
 
+    // Drawing with GL_LUMINANCE_ALPHA means that only the "ink" pixels of the
+    // digits are written into the color buffer, and are multiplied by by the
+    // prevailing glColor.
+
     sprintf (err + strlen(err), " #%d %dx%d", 
              retries, config.width2, config.height2);
 
@@ -1295,11 +1326,85 @@ FAIL:
 }
 
 
+static NSTimeInterval countdown_homestretch_interval = 30;
+
 - (void)updateCountdown
 {
   config.countdown = (usesCountdownTimer
                       ? [countdownDate timeIntervalSince1970]
                       : 0);
+
+  if (countdownHomeStretchStartTimer) {
+    if ([countdownHomeStretchStartTimer isValid])
+      [countdownHomeStretchStartTimer invalidate];
+    [countdownHomeStretchStartTimer release];
+    countdownHomeStretchStartTimer = 0;
+  }
+
+  if (countdownHomeStretchEndTimer) {
+    if ([countdownHomeStretchEndTimer isValid])
+      [countdownHomeStretchEndTimer invalidate];
+    [countdownHomeStretchEndTimer release];
+    countdownHomeStretchEndTimer = 0;
+  }
+
+  [self countdownHomeStretch];
+
+  if (usesCountdownTimer && usesHomeStretchTimer) {
+
+    NSDate *now = [NSDate date];
+    NSDate *start =
+      [NSDate dateWithTimeInterval: -countdown_homestretch_interval
+                         sinceDate: countdownDate];
+    NSDate *end =
+      [NSDate dateWithTimeInterval: countdown_homestretch_interval
+                         sinceDate: countdownDate];
+    NSTimeInterval delay1 = [start timeIntervalSinceDate: now];
+    NSTimeInterval delay2 = [end   timeIntervalSinceDate: now];
+
+    delay1 -= 1.5;  // start a little earlier
+
+    if (delay1 > 0) {
+      countdownHomeStretchStartTimer =
+        [NSTimer timerWithTimeInterval:delay1
+                                target:self
+                              selector:@selector(countdownHomeStretch)
+                              userInfo:nil
+                               repeats:NO];
+      [countdownHomeStretchStartTimer retain];
+      // Without this, the timer doesn't fire...
+      NSRunLoop *L = [NSRunLoop currentRunLoop];
+      [L addTimer:countdownHomeStretchStartTimer forMode:NSDefaultRunLoopMode];
+    }
+
+    if (delay2 > 0) {
+      countdownHomeStretchEndTimer =
+        [NSTimer timerWithTimeInterval:delay2
+                                target:self
+                              selector:@selector(countdownHomeStretch)
+                              userInfo:nil
+                               repeats:NO];
+      [countdownHomeStretchEndTimer retain];
+      // Without this, the timer doesn't fire...
+      NSRunLoop *L = [NSRunLoop currentRunLoop];
+      [L addTimer:countdownHomeStretchEndTimer forMode:NSDefaultRunLoopMode];
+    }
+  }
+}
+
+
+- (void)countdownHomeStretch
+{
+  if (!usesCountdownTimer) return;
+
+  NSTimeInterval secs = [countdownDate timeIntervalSinceNow];
+  if (usesHomeStretchTimer &&
+      secs >= -countdown_homestretch_interval &&
+      secs <   countdown_homestretch_interval) {
+    [self setTimeStyle:SS];
+  } else {
+    [self setTimeStyle:HHMMSS];
+  }
 }
 
 
@@ -1491,8 +1596,30 @@ FAIL:
 - (int)usesCountdownTimer { return usesCountdownTimer; }
 - (void)setUsesCountdownTimer:(int)flag
 {
-  usesCountdownTimer = flag;
-  [self updateCountdown];
+  if (usesCountdownTimer != flag) {
+
+    // If we're in the home stretch while turning off countdown, pop out.
+    NSTimeInterval secs = [countdownDate timeIntervalSinceNow];
+    if (!flag &&
+        usesHomeStretchTimer &&
+        secs >= -countdown_homestretch_interval &&
+        secs <   countdown_homestretch_interval) {
+      [self setTimeStyle:HHMMSS];
+    }
+
+    usesCountdownTimer = flag;
+    [self updateCountdown];
+  }
+}
+
+
+- (int)usesHomeStretchTimer { return usesHomeStretchTimer; }
+- (void)setUsesHomeStretchTimer:(int)flag
+{
+  if (usesHomeStretchTimer != flag) {
+    usesHomeStretchTimer = flag;
+    [self updateCountdown];
+  }
 }
 
 
