@@ -18,7 +18,7 @@
 #define XDALICLOCK_APP_TYPE (xdaliclock_app_get_type())
 G_DECLARE_FINAL_TYPE (XDaliClock, xdaliclock_app, XDALICLOCK, APP,
                       GtkApplication)
-extern void xdaliclock_app_open_prefs (XDaliClock *app);
-extern dali_config *xdaliclock_config (XDaliClock *app);
+extern void xdaliclock_app_open_prefs (XDaliClock *);
+extern dali_config *xdaliclock_config (XDaliClock *);
 
 #endif /* __XDALICLOCK_APP_H__ */
