@@ -22,7 +22,6 @@
 
 #include "xdaliclock.h"
 
-#define DO_TEXTURE	/* Create LUMINANCE_ALPHA data instead of a bitmap */
 #define DO_TEXTURE_RGBA	/* Do RGBA instead of LUMINANCE_ALPHA */
 #define BIGENDIAN	/* Bit ordering if creating a single-bit bitmap */
 
@@ -366,16 +365,17 @@ init_numbers (dali_config *c)
   for (i = 0; i < countof(state->target_digits); i++)
     state->orig_digits[i] = state->target_digits[i] = -1;
 
-  if (! c->bitmap)
-# ifdef DO_TEXTURE
+  if (! c->bitmap) {
+    if (c->bitmap_p) {
+      c->bitmap = calloc (1, c->height2 * c->width / 8);
+    } else {
 #  ifdef DO_TEXTURE_RGBA
-    c->bitmap = calloc (1, c->height2 * c->width2 * 4);
+      c->bitmap = calloc (1, c->height2 * c->width2 * 4);
 #  else
-    c->bitmap = calloc (1, c->height2 * c->width2 * 2);
+      c->bitmap = calloc (1, c->height2 * c->width2 * 2);
 #  endif
-# else  /* !DO_TEXTURE */
-    c->bitmap = calloc (1, c->height2 * (c->width << 3));
-# endif /* !DO_TEXTURE */
+    }
+  }
 
   if (! c->bitmap) abort();
 }
@@ -592,62 +592,57 @@ draw_horizontal_line (dali_config *c, int x1, int x2, int y, BOOL black_p)
       x2 = swap;
     }
 
-# if defined(DO_TEXTURE)
-
-  /* For OpenGL, instead of creating a single-bit bitmap, we create a
-     pixmap with two bytes per pixel where the first byte is FF and
-     the second byte is either FF or 00.  Also, the image is upside
-     down, and the pixmap's dimensions are scaled up to the next
-     highest power of 2.  This is natively usable as GL_LUMINANCE_ALPHA
-     texture data.
-
-     If we could use GL_INTENSITY textures, we could get away with
-     1 byte per pixel instead of 2, but OpenGLES only implements
-     GL_LUMINANCE_ALPHA, not GL_INTENSITY.
-
-     But apparently GL_LUMINANCE_ALPHA has fallen out of favor with more
-     recent versions of OpenGL, so maybe we need to waste 4 bytes instead,
-     and do full RGBA (using only the values FFFFFFFF and FFFFFF00).
-   */
-#  undef NN
-#  ifdef DO_TEXTURE_RGBA
-#   define NN 2
-#  else
-#   define NN 1
-#  endif
-  scanline = c->bitmap + ((c->height-y-1) * c->width2 << NN) + (x1 << NN);
-#  undef NN
-  for (; x1 < x2; x1++)
-    {
-      *scanline++ = 0xFF;
-#  ifdef DO_TEXTURE_RGBA
-      *scanline++ = 0xFF;
-      *scanline++ = 0xFF;
-#  endif
-      *scanline++ = black_p ? 0xFF : 0;
-    }
-
-# elif defined(BIGENDIAN)			/* Single-bit bitmap */
-
+  if (c->bitmap_p) {   				/* Single-bit bitmap */
   scanline = c->bitmap + (y * (c->width2 >> 3));
+
+# ifdef BIGENDIAN
+#  define B (7 - (x1 & 7))
+# else
+#  define B (x1 & 7)
+# endif
+
   if (black_p)
     for (; x1 < x2; x1++)
-      scanline[x1>>3] |= 1 << (7 - (x1 & 7));
+      scanline[x1>>3] |= 1 << B;
   else
     for (; x1 < x2; x1++)
-      scanline[x1>>3] &= ~(1 << (7 - (x1 & 7)));
+      scanline[x1>>3] &= ~(1 << B);
 
-# else  /* !DO_TEXTURE && !BIGENDIAN */
+  } else {
 
-  scanline = c->bitmap + (y * (c->width2 >> 3));
-  if (black_p)
+    /* For OpenGL, instead of creating a single-bit bitmap, we create a
+       pixmap with two bytes per pixel where the first byte is FF and
+       the second byte is either FF or 00.  Also, the image is upside
+       down, and the pixmap's dimensions are scaled up to the next
+       highest power of 2.  This is natively usable as GL_LUMINANCE_ALPHA
+       texture data.
+
+       If we could use GL_INTENSITY textures, we could get away with
+       1 byte per pixel instead of 2, but OpenGLES only implements
+       GL_LUMINANCE_ALPHA, not GL_INTENSITY.
+
+       But apparently GL_LUMINANCE_ALPHA has fallen out of favor with more
+       recent versions of OpenGL, so maybe we need to waste 4 bytes instead,
+       and do full RGBA (using only the values FFFFFFFF and FFFFFF00).
+     */
+#    undef NN
+#    ifdef DO_TEXTURE_RGBA
+#     define NN 2
+#    else
+#     define NN 1
+#    endif
+    scanline = c->bitmap + ((c->height-y-1) * c->width2 << NN) + (x1 << NN);
+#    undef NN
     for (; x1 < x2; x1++)
-      scanline[x1>>3] |= 1 << (x1 & 7);
-  else
-    for (; x1 < x2; x1++)
-      scanline[x1>>3] &= ~(1 << (x1 & 7));
-
-# endif /* !DO_TEXTURE && !BIGENDIAN */
+      {
+        *scanline++ = 0xFF;
+#    ifdef DO_TEXTURE_RGBA
+        *scanline++ = 0xFF;
+        *scanline++ = 0xFF;
+#    endif
+        *scanline++ = black_p ? 0xFF : 0;
+      }
+  }
 }
 
 
@@ -904,7 +899,6 @@ render_once (dali_config *c)
 }
 
 
-#ifdef DO_TEXTURE
 /* return the next larger power of 2. */
 static int
 to_pow2 (int i)
@@ -917,7 +911,6 @@ to_pow2 (int i)
     if (pow2[j] >= i) return pow2[j];
   abort();  /* too big! */
 }
-#endif /* !DO_TEXTURE */
 
 
 void
@@ -926,11 +919,11 @@ render_bitmap_size (dali_config *c,
                     unsigned int *w2_ret, unsigned int *h2_ret)
 {
   pick_font_size (c, w_ret, h_ret);
-# ifdef DO_TEXTURE
-  if (w2_ret) *w2_ret = to_pow2 (*w_ret);
-  if (w2_ret) *h2_ret = to_pow2 (*h_ret);
-# else  /* !DO_TEXTURE */
-  if (w2_ret) *w2_ret = *w_ret;
-  if (w2_ret) *h2_ret = *h_ret;
-# endif /* !DO_TEXTURE */
+  if (c->bitmap_p) {
+    if (w2_ret) *w2_ret = *w_ret;
+    if (w2_ret) *h2_ret = *h_ret;
+  } else {
+    if (w2_ret) *w2_ret = to_pow2 (*w_ret);
+    if (w2_ret) *h2_ret = to_pow2 (*h_ret);
+  }
 }
