@@ -18,6 +18,10 @@
 G_DECLARE_FINAL_TYPE (XDaliClockWindow, xdaliclock_app_window,
                       XDALICLOCK, APP_WINDOW, GtkApplicationWindow)
 extern XDaliClockWindow *xdaliclock_app_window_new (XDaliClock *app,
-                                                    dali_config *c);
+                                                    dali_config *c
+# ifdef DO_SAVER
+                                                    , unsigned long window_id
+# endif
+                                                    );
 
 #endif /* __XDALICLOCK_WINDOW_H__ */
